@@ -1,8 +1,9 @@
-"""Exceptions for Goal Zero Yeti API Python client"""
+"""Exceptions for Goal Zero Yeti API Python client."""
 
 
 class RequestException(IOError):
-    """There was an ambiguous exception that occurred while handling your
+    """There was an ambiguous exception that occurred while handling your.
+
     request.
     """
 
@@ -16,21 +17,25 @@ class RequestException(IOError):
         super().__init__(*args, **kwargs)
 
 
-class ConnectError(RequestException):
+class ConnectError(Exception):
     """When a connection error is encountered."""
 
+    pass  # pylint: disable=unnecessary-pass
 
-class ConnectTimeout(ConnectionError):
+
+class ConnectTimeout(ConnectError):
     """The request timed out while trying to connect to the remote server."""
 
+    pass  # pylint: disable=unnecessary-pass
+
 
 class HostRequired(RequestException):
     """When a host is not provided."""
 
+    pass  # pylint: disable=unnecessary-pass
+
 
 class InvalidHost(RequestException):
     """The URL provided was somehow invalid."""
 
-
-class Timeout(RequestException):
-    """The request timed out."""
+    pass  # pylint: disable=unnecessary-pass
